(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["module", "exports"], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.undefined = mod.exports;
  }
})(this, function (module, exports) {
  "use strict";

  (function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
      var v = factory(require, exports);
      if (v !== undefined) module.exports = v;
    } else if (typeof define === "function" && define.amd) {
      define(["require", "exports", "../promise", "./file-system-record", "fs-extra", "walk", "path"], factory);
    }
  })(function (require, exports) {
    "use strict";

    Object.defineProperty(exports, "__esModule", {
      value: true
    });

    const promise_1 = require("../promise");

    const file_system_record_1 = require("./file-system-record");

    const fs = require("fs-extra");

    const walk = require("walk");

    const path = require("path");

    let fsp = promise_1.default.promisifyAll(fs);

    class Directory extends file_system_record_1.default {
      static createAsync(path) {
        return fsp.mkdirAsync(path);
      }

      static createRecursiveAsync(path) {
        return fsp.mkdirpAsync(path);
      }

      static copyAsync(src, dest) {
        return fsp.copyRecursiveAsync(src, dest);
      }

      static removeAsync(path) {
        return fsp.rmdirAsync(path);
      }

      static removeRecursiveAsync(path) {
        return fsp.removeAsync(path);
      }
      /** Removes all directories in destination with no match in source. */


      static async removeUnmatchedAsync(src, dest, options) {
        const walker = walk.walk(dest);
        const pathsToRemove = [];

        try {
          await Directory.accessAsync(src, file_system_record_1.FileSystemPermission.Visible);
        } catch (error) {
          if (!options || !options.ignoreMissingSource) {
            throw error;
          } else {
            return;
          }
        }

        try {
          await Directory.accessAsync(dest, file_system_record_1.FileSystemPermission.Visible);
        } catch (error) {
          if (!options || !options.ignoreMissingDestination) {
            throw error;
          } else {
            return;
          }
        }

        await new Promise((resolve, reject) => {
          walker.on("errors", (root, nodeStatsArray, next) => {
            reject(nodeStatsArray);
          });
          walker.on("end", () => {
            resolve();
          });
          walker.on("directory", async (root, stat, next) => {
            try {
              await Directory.accessAsync(path.join(src, path.relative(dest, root), stat.name), file_system_record_1.FileSystemPermission.Visible);
            } catch (error) {
              pathsToRemove.push(path.join(root, stat.name));
            }

            next();
          });
        });
        await Promise.all(pathsToRemove.map(async path => {
          await Directory.removeRecursiveAsync(path);
        }));
      }

    }

    exports.default = Directory;
  });
});
//# sourceMappingURL=directory.js.map
