(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["module", "exports"], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.undefined = mod.exports;
  }
})(this, function (module, exports) {
  "use strict";

  (function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
      var v = factory(require, exports);
      if (v !== undefined) module.exports = v;
    } else if (typeof define === "function" && define.amd) {
      define(["require", "exports", "./directory", "./file", "./file-system-record", "del", "gulp", "gulp-flatten", "gulp-if"], factory);
    }
  })(function (require, exports) {
    "use strict";

    Object.defineProperty(exports, "__esModule", {
      value: true
    });

    var directory_1 = require("./directory");

    exports.Directory = directory_1.default;

    var file_1 = require("./file");

    exports.File = file_1.default;

    var file_system_record_1 = require("./file-system-record");

    exports.FileSystemRecord = file_system_record_1.default;
    exports.FileSystemPermission = file_system_record_1.FileSystemPermission; // import Promise from "../promise";

    const del = require("del");

    const gulp = require("gulp");

    const flatten = require("gulp-flatten");

    const gulpif = require("gulp-if");

    async function copyPatternsAsync(sourcePatterns, destination, options) {
      // if (!options) options = {};
      // if (!options.stopOnErr) options.stopOnErr = true;
      // Using path.basename will result in a flatten when multiple
      // source directories are specified. Another option would be
      // to find the common base and create the relative subfolders.
      // let matches: string[] = await globp(sourcePatterns, options.globOptions);
      // for (let i = 0; i < matches.length; ++i) {
      //   let match = matches[i];
      //   await ncpp(match, path.join(destination, path.basename(match)), options);
      // }
      return new Promise((resolve, reject) => {
        let destinationOptions;
        if (options && options.mode) destinationOptions = {
          mode: options.mode
        };
        gulp.src(sourcePatterns, options).pipe(gulpif(options && options.flatten, flatten())).pipe(gulp.dest(destination, destinationOptions)).on("end", resolve).on("error", reject);
      });
    }

    exports.copyPatternsAsync = copyPatternsAsync;

    async function removePatternsAsync(patterns, options) {
      return await del(patterns, options);
    }

    exports.removePatternsAsync = removePatternsAsync;

    function removePatterns(patterns, options) {
      return del.sync(patterns, options);
    }

    exports.removePatterns = removePatterns;
  });
});
//# sourceMappingURL=index.js.map
