(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["module", "exports"], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.undefined = mod.exports;
  }
})(this, function (module, exports) {
  "use strict";

  (function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
      var v = factory(require, exports);
      if (v !== undefined) module.exports = v;
    } else if (typeof define === "function" && define.amd) {
      define(["require", "exports", "os"], factory);
    }
  })(function (require, exports) {
    "use strict";

    Object.defineProperty(exports, "__esModule", {
      value: true
    });

    const os = require("os");

    var Architecture;

    (function (Architecture) {
      Architecture[Architecture["X64"] = 0] = "X64";
      Architecture[Architecture["IA32"] = 1] = "IA32";
      Architecture[Architecture["ARM"] = 2] = "ARM";
      Architecture[Architecture["Other"] = 3] = "Other";
    })(Architecture = exports.Architecture || (exports.Architecture = {}));

    var Platform;

    (function (Platform) {
      Platform[Platform["Darwin"] = 0] = "Darwin";
      Platform[Platform["FreeBSD"] = 1] = "FreeBSD";
      Platform[Platform["Linux"] = 2] = "Linux";
      Platform[Platform["SunOS"] = 3] = "SunOS";
      Platform[Platform["Win32"] = 4] = "Win32";
      Platform[Platform["Other"] = 5] = "Other";
    })(Platform = exports.Platform || (exports.Platform = {}));

    var Endianness;

    (function (Endianness) {
      Endianness[Endianness["Big"] = 0] = "Big";
      Endianness[Endianness["Little"] = 1] = "Little";
    })(Endianness = exports.Endianness || (exports.Endianness = {}));

    class OperatingSystemProvider {
      static get default() {
        if (!OperatingSystemProvider._instance) {
          if (process) {
            // process == node, window == browser
            OperatingSystemProvider._instance = new NodeOperatingSystem();
          }
        }

        return OperatingSystemProvider._instance;
      }

    }

    exports.OperatingSystemProvider = OperatingSystemProvider;

    class NodeOperatingSystem {
      constructor() {
        this.eol = os.EOL;
      }

      get architecture() {
        switch (os.arch()) {
          case "x64":
            return Architecture.X64;

          case "ia32":
            return Architecture.IA32;

          case "arm":
            return Architecture.ARM;

          default:
            return Architecture.Other;
        }
      }

      get cpus() {
        return os.cpus();
      }

      get endianness() {
        if (os.endianness() === "BE") return Endianness.Big;
        return Endianness.Little;
      }

      get freeMemory() {
        return os.freemem();
      }

      get homeDirectory() {
        return os.homedir();
      }

      get hostName() {
        return os.hostname();
      }

      get loadAverages() {
        return os.loadavg();
      }

      get networkInterfaces() {
        return os.networkInterfaces();
      }

      get platform() {
        switch (os.platform()) {
          case "darwin":
            return Platform.Darwin;

          case "freebsd":
            return Platform.FreeBSD;

          case "linux":
            return Platform.Linux;

          case "sunos":
            return Platform.SunOS;

          case "win32":
            return Platform.Win32;

          default:
            return Platform.Other;
        }
      }

      get release() {
        return os.release();
      }

      get tempDirectory() {
        return os.tmpdir();
      }

      get totalMemory() {
        return os.totalmem();
      }

      get uptimeSeconds() {
        return os.uptime();
      }

      get user() {
        return this.getUser();
      }

      getUser(options) {
        return os.userInfo(options);
      }

    }
  });
});
//# sourceMappingURL=operating-system.js.map
